# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ShareConfigAllowIpAccessRule',
    'ShareConfigAllowRefererAccessRule',
    'ShareConfigAllowRefererAccessRuleCommonType',
    'ShareConfigCommonMatchs',
    'ShareConfigCommonMatchsCommonType',
    'ShareConfigDenyIpAccessRule',
    'ShareConfigDenyRefererAccessRule',
    'ShareConfigDenyRefererAccessRuleCommonType',
    'GetShareConfigAllowIpAccessRuleResult',
    'GetShareConfigAllowRefererAccessRuleResult',
    'GetShareConfigAllowRefererAccessRuleCommonTypeResult',
    'GetShareConfigCommonMatchsResult',
    'GetShareConfigCommonMatchsCommonTypeResult',
    'GetShareConfigDenyIpAccessRuleResult',
    'GetShareConfigDenyRefererAccessRuleResult',
    'GetShareConfigDenyRefererAccessRuleCommonTypeResult',
]

@pulumi.output_type
class ShareConfigAllowIpAccessRule(dict):
    def __init__(__self__, *,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param Sequence[builtins.str] rules: 表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigAllowRefererAccessRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowEmpty":
            suggest = "allow_empty"
        elif key == "commonType":
            suggest = "common_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigAllowRefererAccessRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigAllowRefererAccessRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigAllowRefererAccessRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_empty: Optional[builtins.bool] = None,
                 common_type: Optional['outputs.ShareConfigAllowRefererAccessRuleCommonType'] = None):
        """
        :param builtins.bool allow_empty: 表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        :param 'ShareConfigAllowRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[builtins.bool]:
        """
        表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional['outputs.ShareConfigAllowRefererAccessRuleCommonType']:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class ShareConfigAllowRefererAccessRuleCommonType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ignoreCase":
            suggest = "ignore_case"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigAllowRefererAccessRuleCommonType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigAllowRefererAccessRuleCommonType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigAllowRefererAccessRuleCommonType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ignore_case: Optional[builtins.bool] = None,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigCommonMatchs(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "commonType":
            suggest = "common_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigCommonMatchs. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigCommonMatchs.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigCommonMatchs.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 common_type: Optional['outputs.ShareConfigCommonMatchsCommonType'] = None):
        """
        :param 'ShareConfigCommonMatchsCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional['outputs.ShareConfigCommonMatchsCommonType']:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class ShareConfigCommonMatchsCommonType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ignoreCase":
            suggest = "ignore_case"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigCommonMatchsCommonType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigCommonMatchsCommonType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigCommonMatchsCommonType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ignore_case: Optional[builtins.bool] = None,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigDenyIpAccessRule(dict):
    def __init__(__self__, *,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param Sequence[builtins.str] rules: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class ShareConfigDenyRefererAccessRule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "allowEmpty":
            suggest = "allow_empty"
        elif key == "commonType":
            suggest = "common_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigDenyRefererAccessRule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigDenyRefererAccessRule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigDenyRefererAccessRule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allow_empty: Optional[builtins.bool] = None,
                 common_type: Optional['outputs.ShareConfigDenyRefererAccessRuleCommonType'] = None):
        """
        :param builtins.bool allow_empty: 表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        :param 'ShareConfigDenyRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        if allow_empty is not None:
            pulumi.set(__self__, "allow_empty", allow_empty)
        if common_type is not None:
            pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> Optional[builtins.bool]:
        """
        表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> Optional['outputs.ShareConfigDenyRefererAccessRuleCommonType']:
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class ShareConfigDenyRefererAccessRuleCommonType(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ignoreCase":
            suggest = "ignore_case"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ShareConfigDenyRefererAccessRuleCommonType. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ShareConfigDenyRefererAccessRuleCommonType.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ShareConfigDenyRefererAccessRuleCommonType.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ignore_case: Optional[builtins.bool] = None,
                 rules: Optional[Sequence[builtins.str]] = None):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        if ignore_case is not None:
            pulumi.set(__self__, "ignore_case", ignore_case)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Optional[Sequence[builtins.str]]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigAllowIpAccessRuleResult(dict):
    def __init__(__self__, *,
                 rules: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] rules: 表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表。列表中的每个条目是一个 IP 地址或 CIDR 网段。IP 地址和网段可以是 IPv4 和 IPv6 格式。列表的额度如下：对于 AddSharedConfig，列表中条目的数量不能超过 30,000 个。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigAllowRefererAccessRuleResult(dict):
    def __init__(__self__, *,
                 allow_empty: builtins.bool,
                 common_type: 'outputs.GetShareConfigAllowRefererAccessRuleCommonTypeResult'):
        """
        :param builtins.bool allow_empty: 表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        :param 'GetShareConfigAllowRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        pulumi.set(__self__, "allow_empty", allow_empty)
        pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> builtins.bool:
        """
        表示是否不允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。false：表示允许。该参数的默认值是 false。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> 'outputs.GetShareConfigAllowRefererAccessRuleCommonTypeResult':
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class GetShareConfigAllowRefererAccessRuleCommonTypeResult(dict):
    def __init__(__self__, *,
                 ignore_case: builtins.bool,
                 rules: Sequence[builtins.str]):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        pulumi.set(__self__, "ignore_case", ignore_case)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> builtins.bool:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigCommonMatchsResult(dict):
    def __init__(__self__, *,
                 common_type: 'outputs.GetShareConfigCommonMatchsCommonTypeResult'):
        """
        :param 'GetShareConfigCommonMatchsCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> 'outputs.GetShareConfigCommonMatchsCommonTypeResult':
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class GetShareConfigCommonMatchsCommonTypeResult(dict):
    def __init__(__self__, *,
                 ignore_case: builtins.bool,
                 rules: Sequence[builtins.str]):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        pulumi.set(__self__, "ignore_case", ignore_case)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> builtins.bool:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigDenyIpAccessRuleResult(dict):
    def __init__(__self__, *,
                 rules: Sequence[builtins.str]):
        """
        :param Sequence[builtins.str] rules: 表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个 IP 黑名单的配置，对应 ConfigType 是 deny*ip*access_rule。
        """
        return pulumi.get(self, "rules")


@pulumi.output_type
class GetShareConfigDenyRefererAccessRuleResult(dict):
    def __init__(__self__, *,
                 allow_empty: builtins.bool,
                 common_type: 'outputs.GetShareConfigDenyRefererAccessRuleCommonTypeResult'):
        """
        :param builtins.bool allow_empty: 表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        :param 'GetShareConfigDenyRefererAccessRuleCommonTypeArgs' common_type: 表示该通用列表的内容。
        """
        pulumi.set(__self__, "allow_empty", allow_empty)
        pulumi.set(__self__, "common_type", common_type)

    @property
    @pulumi.getter(name="allowEmpty")
    def allow_empty(self) -> builtins.bool:
        """
        表示是否允许 Referer 头部为空或者不包含 Referer 头部的请求。该参数有以下取值：true：表示允许。false：表示不允许。如果请求的 Referer 头部为空或者不包含 Referer 头部，内容分发网络拒绝请求。该参数的默认值是 true。
        """
        return pulumi.get(self, "allow_empty")

    @property
    @pulumi.getter(name="commonType")
    def common_type(self) -> 'outputs.GetShareConfigDenyRefererAccessRuleCommonTypeResult':
        """
        表示该通用列表的内容。
        """
        return pulumi.get(self, "common_type")


@pulumi.output_type
class GetShareConfigDenyRefererAccessRuleCommonTypeResult(dict):
    def __init__(__self__, *,
                 ignore_case: builtins.bool,
                 rules: Sequence[builtins.str]):
        """
        :param builtins.bool ignore_case: 表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        :param Sequence[builtins.str] rules: 表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        pulumi.set(__self__, "ignore_case", ignore_case)
        pulumi.set(__self__, "rules", rules)

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> builtins.bool:
        """
        表示 Rules 中的条目是否区分大小写。该参数有以下取值：true：表示不区分大小写。false：表示区分大小写。该参数的默认值是 true。
        """
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter
    def rules(self) -> Sequence[builtins.str]:
        """
        表示一个条目列表，列表中的每个条目是一个字符串。列表的额度如下：列表最多可以包含 4,000 个条目。所有条目的总长度不能超过 200,000 个字符。CDN 在创建该全局配置时，会将列表中重复的条目删除。重复条目不占额度。
        """
        return pulumi.get(self, "rules")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KafkaTriggerArgs', 'KafkaTrigger']

@pulumi.input_type
class KafkaTriggerArgs:
    def __init__(__self__, *,
                 function_id: pulumi.Input[builtins.str],
                 mq_instance_id: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 topic_name: pulumi.Input[builtins.str],
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 kafka_credentials: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a KafkaTrigger resource.
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input['KafkaTriggerKafkaCredentialsArgs'] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        pulumi.set(__self__, "function_id", function_id)
        pulumi.set(__self__, "mq_instance_id", mq_instance_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "topic_name", topic_name)
        if batch_flush_duration_milliseconds is not None:
            pulumi.set(__self__, "batch_flush_duration_milliseconds", batch_flush_duration_milliseconds)
        if batch_size is not None:
            pulumi.set(__self__, "batch_size", batch_size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if kafka_credentials is not None:
            pulumi.set(__self__, "kafka_credentials", kafka_credentials)
        if maximum_retry_attempts is not None:
            pulumi.set(__self__, "maximum_retry_attempts", maximum_retry_attempts)
        if starting_position is not None:
            pulumi.set(__self__, "starting_position", starting_position)

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> pulumi.Input[builtins.str]:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @function_id.setter
    def function_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "function_id", value)

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> pulumi.Input[builtins.str]:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @mq_instance_id.setter
    def mq_instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mq_instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Input[builtins.str]:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @batch_flush_duration_milliseconds.setter
    def batch_flush_duration_milliseconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_flush_duration_milliseconds", value)

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @batch_size.setter
    def batch_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_size", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]:
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @kafka_credentials.setter
    def kafka_credentials(self, value: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]):
        pulumi.set(self, "kafka_credentials", value)

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @maximum_retry_attempts.setter
    def maximum_retry_attempts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "maximum_retry_attempts", value)

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @starting_position.setter
    def starting_position(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "starting_position", value)


@pulumi.input_type
class _KafkaTriggerState:
    def __init__(__self__, *,
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 consumer_group: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 kafka_credentials: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']] = None,
                 kafka_trigger_id: Optional[pulumi.Input[builtins.str]] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering KafkaTrigger resources.
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] consumer_group: 消息队列 Kafka 实例的消费组名字。
        :param pulumi.Input[builtins.str] created_time: Kafka 触发器创建时间。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input['KafkaTriggerKafkaCredentialsArgs'] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.str] kafka_trigger_id: Kafka 触发器 ID。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        :param pulumi.Input[builtins.str] status: Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        :param pulumi.Input[builtins.str] updated_time: Kafka 触发器最近一次更新时间。
        """
        if batch_flush_duration_milliseconds is not None:
            pulumi.set(__self__, "batch_flush_duration_milliseconds", batch_flush_duration_milliseconds)
        if batch_size is not None:
            pulumi.set(__self__, "batch_size", batch_size)
        if consumer_group is not None:
            pulumi.set(__self__, "consumer_group", consumer_group)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if function_id is not None:
            pulumi.set(__self__, "function_id", function_id)
        if kafka_credentials is not None:
            pulumi.set(__self__, "kafka_credentials", kafka_credentials)
        if kafka_trigger_id is not None:
            pulumi.set(__self__, "kafka_trigger_id", kafka_trigger_id)
        if maximum_retry_attempts is not None:
            pulumi.set(__self__, "maximum_retry_attempts", maximum_retry_attempts)
        if mq_instance_id is not None:
            pulumi.set(__self__, "mq_instance_id", mq_instance_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if starting_position is not None:
            pulumi.set(__self__, "starting_position", starting_position)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @batch_flush_duration_milliseconds.setter
    def batch_flush_duration_milliseconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_flush_duration_milliseconds", value)

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @batch_size.setter
    def batch_size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "batch_size", value)

    @property
    @pulumi.getter(name="consumerGroup")
    def consumer_group(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        消息队列 Kafka 实例的消费组名字。
        """
        return pulumi.get(self, "consumer_group")

    @consumer_group.setter
    def consumer_group(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "consumer_group", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @function_id.setter
    def function_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "function_id", value)

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]:
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @kafka_credentials.setter
    def kafka_credentials(self, value: Optional[pulumi.Input['KafkaTriggerKafkaCredentialsArgs']]):
        pulumi.set(self, "kafka_credentials", value)

    @property
    @pulumi.getter(name="kafkaTriggerId")
    def kafka_trigger_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器 ID。
        """
        return pulumi.get(self, "kafka_trigger_id")

    @kafka_trigger_id.setter
    def kafka_trigger_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kafka_trigger_id", value)

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @maximum_retry_attempts.setter
    def maximum_retry_attempts(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "maximum_retry_attempts", value)

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @mq_instance_id.setter
    def mq_instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mq_instance_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @starting_position.setter
    def starting_position(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "starting_position", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Kafka 触发器最近一次更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vefaas/kafkaTrigger:KafkaTrigger")
class KafkaTrigger(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 kafka_credentials: Optional[pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']]] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        函数服务支持对接消息队列 Kafka 版。通过创建 Kafka 触发器，函数服务将作为消费者消费 Kafka 中的消息，并将消息传递给用户函数，触发函数代码逻辑。您无需关心函数服务消费消息的细节，只需编写处理消息的函数。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vefaas_trigger_demo = bytepluscc.vefaas.KafkaTrigger("VefaasTriggerDemo",
            function_id="djb27tnr****",
            name="VefaasTriggerDemo",
            maximum_retry_attempts=74,
            starting_position="Earliest",
            enabled=False,
            kafka_credentials={
                "mechanism": "PLAIN",
                "username": "VefaasTriggerDemo",
                "password": "*****",
            },
            mq_instance_id="kafka-cnng8cm4q2fncrvs****",
            topic_name="VefaasTriggerDemo",
            description="VefaasTriggerDemo description",
            batch_flush_duration_milliseconds=8637,
            batch_size=709)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vefaas/kafkaTrigger:KafkaTrigger example "function_id|kafka_trigger_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KafkaTriggerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        函数服务支持对接消息队列 Kafka 版。通过创建 Kafka 触发器，函数服务将作为消费者消费 Kafka 中的消息，并将消息传递给用户函数，触发函数代码逻辑。您无需关心函数服务消费消息的细节，只需编写处理消息的函数。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vefaas_trigger_demo = bytepluscc.vefaas.KafkaTrigger("VefaasTriggerDemo",
            function_id="djb27tnr****",
            name="VefaasTriggerDemo",
            maximum_retry_attempts=74,
            starting_position="Earliest",
            enabled=False,
            kafka_credentials={
                "mechanism": "PLAIN",
                "username": "VefaasTriggerDemo",
                "password": "*****",
            },
            mq_instance_id="kafka-cnng8cm4q2fncrvs****",
            topic_name="VefaasTriggerDemo",
            description="VefaasTriggerDemo description",
            batch_flush_duration_milliseconds=8637,
            batch_size=709)
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vefaas/kafkaTrigger:KafkaTrigger example "function_id|kafka_trigger_id"
        ```

        :param str resource_name: The name of the resource.
        :param KafkaTriggerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KafkaTriggerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
                 batch_size: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 function_id: Optional[pulumi.Input[builtins.str]] = None,
                 kafka_credentials: Optional[pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']]] = None,
                 maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
                 mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 starting_position: Optional[pulumi.Input[builtins.str]] = None,
                 topic_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KafkaTriggerArgs.__new__(KafkaTriggerArgs)

            __props__.__dict__["batch_flush_duration_milliseconds"] = batch_flush_duration_milliseconds
            __props__.__dict__["batch_size"] = batch_size
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            if function_id is None and not opts.urn:
                raise TypeError("Missing required property 'function_id'")
            __props__.__dict__["function_id"] = function_id
            __props__.__dict__["kafka_credentials"] = kafka_credentials
            __props__.__dict__["maximum_retry_attempts"] = maximum_retry_attempts
            if mq_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'mq_instance_id'")
            __props__.__dict__["mq_instance_id"] = mq_instance_id
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["starting_position"] = starting_position
            if topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'topic_name'")
            __props__.__dict__["topic_name"] = topic_name
            __props__.__dict__["consumer_group"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["kafka_trigger_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(KafkaTrigger, __self__).__init__(
            'bytepluscc:vefaas/kafkaTrigger:KafkaTrigger',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            batch_flush_duration_milliseconds: Optional[pulumi.Input[builtins.int]] = None,
            batch_size: Optional[pulumi.Input[builtins.int]] = None,
            consumer_group: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enabled: Optional[pulumi.Input[builtins.bool]] = None,
            function_id: Optional[pulumi.Input[builtins.str]] = None,
            kafka_credentials: Optional[pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']]] = None,
            kafka_trigger_id: Optional[pulumi.Input[builtins.str]] = None,
            maximum_retry_attempts: Optional[pulumi.Input[builtins.int]] = None,
            mq_instance_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            starting_position: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            topic_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'KafkaTrigger':
        """
        Get an existing KafkaTrigger resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] batch_flush_duration_milliseconds: 触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        :param pulumi.Input[builtins.int] batch_size: 触发器批量消费的每批次消息数。
        :param pulumi.Input[builtins.str] consumer_group: 消息队列 Kafka 实例的消费组名字。
        :param pulumi.Input[builtins.str] created_time: Kafka 触发器创建时间。
        :param pulumi.Input[builtins.str] description: Kafka 触发器描述。长度限制为 200 个字符以内。
        :param pulumi.Input[builtins.bool] enabled: 是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        :param pulumi.Input[builtins.str] function_id: 函数 ID。
        :param pulumi.Input[Union['KafkaTriggerKafkaCredentialsArgs', 'KafkaTriggerKafkaCredentialsArgsDict']] kafka_credentials: Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        :param pulumi.Input[builtins.str] kafka_trigger_id: Kafka 触发器 ID。
        :param pulumi.Input[builtins.int] maximum_retry_attempts: 函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        :param pulumi.Input[builtins.str] mq_instance_id: 消息队列 Kafka 实例 ID。
        :param pulumi.Input[builtins.str] name: Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        :param pulumi.Input[builtins.str] starting_position: 指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        :param pulumi.Input[builtins.str] status: Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        :param pulumi.Input[builtins.str] topic_name: 消息队列 Kafka 实例的 Topic 名称。
        :param pulumi.Input[builtins.str] updated_time: Kafka 触发器最近一次更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KafkaTriggerState.__new__(_KafkaTriggerState)

        __props__.__dict__["batch_flush_duration_milliseconds"] = batch_flush_duration_milliseconds
        __props__.__dict__["batch_size"] = batch_size
        __props__.__dict__["consumer_group"] = consumer_group
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["function_id"] = function_id
        __props__.__dict__["kafka_credentials"] = kafka_credentials
        __props__.__dict__["kafka_trigger_id"] = kafka_trigger_id
        __props__.__dict__["maximum_retry_attempts"] = maximum_retry_attempts
        __props__.__dict__["mq_instance_id"] = mq_instance_id
        __props__.__dict__["name"] = name
        __props__.__dict__["starting_position"] = starting_position
        __props__.__dict__["status"] = status
        __props__.__dict__["topic_name"] = topic_name
        __props__.__dict__["updated_time"] = updated_time
        return KafkaTrigger(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="batchFlushDurationMilliseconds")
    def batch_flush_duration_milliseconds(self) -> pulumi.Output[builtins.int]:
        """
        触发器批量消费的最长等待时间。单位为毫秒（ms），取值范围为 1000 ~ 60000 ms，默认值为 1000 ms。
        """
        return pulumi.get(self, "batch_flush_duration_milliseconds")

    @property
    @pulumi.getter(name="batchSize")
    def batch_size(self) -> pulumi.Output[builtins.int]:
        """
        触发器批量消费的每批次消息数。
        """
        return pulumi.get(self, "batch_size")

    @property
    @pulumi.getter(name="consumerGroup")
    def consumer_group(self) -> pulumi.Output[builtins.str]:
        """
        消息队列 Kafka 实例的消费组名字。
        """
        return pulumi.get(self, "consumer_group")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器描述。长度限制为 200 个字符以内。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否在创建触发器的同时启用触发器。取值：true：启用。false：关闭。
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="functionId")
    def function_id(self) -> pulumi.Output[builtins.str]:
        """
        函数 ID。
        """
        return pulumi.get(self, "function_id")

    @property
    @pulumi.getter(name="kafkaCredentials")
    def kafka_credentials(self) -> pulumi.Output['outputs.KafkaTriggerKafkaCredentials']:
        """
        Kafka 身份认证。函数服务将通过 Kafka ACL 权限策略，对 PLAIN 和 SCRAM-SHA-256 两种类型的 SASL 用户进行消息消费鉴权。
        """
        return pulumi.get(self, "kafka_credentials")

    @property
    @pulumi.getter(name="kafkaTriggerId")
    def kafka_trigger_id(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器 ID。
        """
        return pulumi.get(self, "kafka_trigger_id")

    @property
    @pulumi.getter(name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> pulumi.Output[builtins.int]:
        """
        函数发生运行错误（包括用户代码错误和 Runtime 错误）时的最大重试次数。取值范围为 0～100 的正整数。
        """
        return pulumi.get(self, "maximum_retry_attempts")

    @property
    @pulumi.getter(name="mqInstanceId")
    def mq_instance_id(self) -> pulumi.Output[builtins.str]:
        """
        消息队列 Kafka 实例 ID。
        """
        return pulumi.get(self, "mq_instance_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器名字。同一函数下，触发器名称不可重复。只能包含大小写字母、数字、下划线，并且以字母开头，长度限制为 4~63 个字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="startingPosition")
    def starting_position(self) -> pulumi.Output[builtins.str]:
        """
        指定开始消费 Topic 中消息的位置。取值：Latest：只消费订阅 Topic 后产生的消息。Earliest：从 Topic 中生产的第一条消息开始消费。
        """
        return pulumi.get(self, "starting_position")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器状态。参数值说明：ready：运行，failed：失败，pending：启动中
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Output[builtins.str]:
        """
        消息队列 Kafka 实例的 Topic 名称。
        """
        return pulumi.get(self, "topic_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        Kafka 触发器最近一次更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from ._inputs import *

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[builtins.str]] = None,
                 assume_role: Optional[pulumi.Input['ProviderAssumeRoleArgs']] = None,
                 customer_headers: Optional[pulumi.Input[builtins.str]] = None,
                 disable_ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input['ProviderEndpointsArgs']] = None,
                 proxy_url: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[builtins.str] access_key: The Access Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_ACCESS_KEY`
               environment variable
        :param pulumi.Input['ProviderAssumeRoleArgs'] assume_role: An `assume_role` block (documented below). Only one `assume_role` block may be in the configuration.
        :param pulumi.Input[builtins.str] customer_headers: CUSTOMER HEADERS for Byteplus Provider. The customer_headers field uses commas (,) to separate multiple headers, and
               colons (:) to separate each header key from its corresponding value.
        :param pulumi.Input[builtins.bool] disable_ssl: Disable SSL for Byteplus Provider
        :param pulumi.Input['ProviderEndpointsArgs'] endpoints: An `endpoints` block (documented below). Only one `endpoints` block may be in the configuration.
        :param pulumi.Input[builtins.str] proxy_url: PROXY URL for Byteplus Provider
        :param pulumi.Input[builtins.str] region: The Region for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_REGION` environment
               variable
        :param pulumi.Input[builtins.str] secret_key: he Secret Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_SECRET_KEY`
               environment variable
        """
        if access_key is None:
            access_key = _utilities.get_env('BYTEPLUS_ACCESS_KEY')
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if assume_role is not None:
            pulumi.set(__self__, "assume_role", assume_role)
        if customer_headers is None:
            customer_headers = _utilities.get_env('BYTEPLUS_CUSTOMER_HEADERS')
        if customer_headers is not None:
            pulumi.set(__self__, "customer_headers", customer_headers)
        if disable_ssl is None:
            disable_ssl = _utilities.get_env_bool('BYTEPLUS_DISABLE_SSL')
        if disable_ssl is not None:
            pulumi.set(__self__, "disable_ssl", disable_ssl)
        if endpoints is not None:
            pulumi.set(__self__, "endpoints", endpoints)
        if proxy_url is None:
            proxy_url = _utilities.get_env('BYTEPLUS_PROXY_URL')
        if proxy_url is not None:
            pulumi.set(__self__, "proxy_url", proxy_url)
        if region is None:
            region = _utilities.get_env('BYTEPLUS_REGION')
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is None:
            secret_key = _utilities.get_env('BYTEPLUS_SECRET_KEY')
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Access Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_ACCESS_KEY`
        environment variable
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "access_key", value)

    @property
    @pulumi.getter(name="assumeRole")
    def assume_role(self) -> Optional[pulumi.Input['ProviderAssumeRoleArgs']]:
        """
        An `assume_role` block (documented below). Only one `assume_role` block may be in the configuration.
        """
        return pulumi.get(self, "assume_role")

    @assume_role.setter
    def assume_role(self, value: Optional[pulumi.Input['ProviderAssumeRoleArgs']]):
        pulumi.set(self, "assume_role", value)

    @property
    @pulumi.getter(name="customerHeaders")
    def customer_headers(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        CUSTOMER HEADERS for Byteplus Provider. The customer_headers field uses commas (,) to separate multiple headers, and
        colons (:) to separate each header key from its corresponding value.
        """
        return pulumi.get(self, "customer_headers")

    @customer_headers.setter
    def customer_headers(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customer_headers", value)

    @property
    @pulumi.getter(name="disableSsl")
    def disable_ssl(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Disable SSL for Byteplus Provider
        """
        return pulumi.get(self, "disable_ssl")

    @disable_ssl.setter
    def disable_ssl(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "disable_ssl", value)

    @property
    @pulumi.getter
    def endpoints(self) -> Optional[pulumi.Input['ProviderEndpointsArgs']]:
        """
        An `endpoints` block (documented below). Only one `endpoints` block may be in the configuration.
        """
        return pulumi.get(self, "endpoints")

    @endpoints.setter
    def endpoints(self, value: Optional[pulumi.Input['ProviderEndpointsArgs']]):
        pulumi.set(self, "endpoints", value)

    @property
    @pulumi.getter(name="proxyUrl")
    def proxy_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        PROXY URL for Byteplus Provider
        """
        return pulumi.get(self, "proxy_url")

    @proxy_url.setter
    def proxy_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "proxy_url", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Region for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_REGION` environment
        variable
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        he Secret Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_SECRET_KEY`
        environment variable
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "secret_key", value)


@pulumi.type_token("pulumi:providers:bytepluscc")
class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[builtins.str]] = None,
                 assume_role: Optional[pulumi.Input[Union['ProviderAssumeRoleArgs', 'ProviderAssumeRoleArgsDict']]] = None,
                 customer_headers: Optional[pulumi.Input[builtins.str]] = None,
                 disable_ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input[Union['ProviderEndpointsArgs', 'ProviderEndpointsArgsDict']]] = None,
                 proxy_url: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        The provider type for the bytepluscc package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] access_key: The Access Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_ACCESS_KEY`
               environment variable
        :param pulumi.Input[Union['ProviderAssumeRoleArgs', 'ProviderAssumeRoleArgsDict']] assume_role: An `assume_role` block (documented below). Only one `assume_role` block may be in the configuration.
        :param pulumi.Input[builtins.str] customer_headers: CUSTOMER HEADERS for Byteplus Provider. The customer_headers field uses commas (,) to separate multiple headers, and
               colons (:) to separate each header key from its corresponding value.
        :param pulumi.Input[builtins.bool] disable_ssl: Disable SSL for Byteplus Provider
        :param pulumi.Input[Union['ProviderEndpointsArgs', 'ProviderEndpointsArgsDict']] endpoints: An `endpoints` block (documented below). Only one `endpoints` block may be in the configuration.
        :param pulumi.Input[builtins.str] proxy_url: PROXY URL for Byteplus Provider
        :param pulumi.Input[builtins.str] region: The Region for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_REGION` environment
               variable
        :param pulumi.Input[builtins.str] secret_key: he Secret Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_SECRET_KEY`
               environment variable
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the bytepluscc package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key: Optional[pulumi.Input[builtins.str]] = None,
                 assume_role: Optional[pulumi.Input[Union['ProviderAssumeRoleArgs', 'ProviderAssumeRoleArgsDict']]] = None,
                 customer_headers: Optional[pulumi.Input[builtins.str]] = None,
                 disable_ssl: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoints: Optional[pulumi.Input[Union['ProviderEndpointsArgs', 'ProviderEndpointsArgsDict']]] = None,
                 proxy_url: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            if access_key is None:
                access_key = _utilities.get_env('BYTEPLUS_ACCESS_KEY')
            __props__.__dict__["access_key"] = access_key
            __props__.__dict__["assume_role"] = pulumi.Output.from_input(assume_role).apply(pulumi.runtime.to_json) if assume_role is not None else None
            if customer_headers is None:
                customer_headers = _utilities.get_env('BYTEPLUS_CUSTOMER_HEADERS')
            __props__.__dict__["customer_headers"] = customer_headers
            if disable_ssl is None:
                disable_ssl = _utilities.get_env_bool('BYTEPLUS_DISABLE_SSL')
            __props__.__dict__["disable_ssl"] = pulumi.Output.from_input(disable_ssl).apply(pulumi.runtime.to_json) if disable_ssl is not None else None
            __props__.__dict__["endpoints"] = pulumi.Output.from_input(endpoints).apply(pulumi.runtime.to_json) if endpoints is not None else None
            if proxy_url is None:
                proxy_url = _utilities.get_env('BYTEPLUS_PROXY_URL')
            __props__.__dict__["proxy_url"] = proxy_url
            if region is None:
                region = _utilities.get_env('BYTEPLUS_REGION')
            __props__.__dict__["region"] = region
            if secret_key is None:
                secret_key = _utilities.get_env('BYTEPLUS_SECRET_KEY')
            __props__.__dict__["secret_key"] = secret_key
        super(Provider, __self__).__init__(
            'bytepluscc',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Access Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_ACCESS_KEY`
        environment variable
        """
        return pulumi.get(self, "access_key")

    @property
    @pulumi.getter(name="customerHeaders")
    def customer_headers(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        CUSTOMER HEADERS for Byteplus Provider. The customer_headers field uses commas (,) to separate multiple headers, and
        colons (:) to separate each header key from its corresponding value.
        """
        return pulumi.get(self, "customer_headers")

    @property
    @pulumi.getter(name="proxyUrl")
    def proxy_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        PROXY URL for Byteplus Provider
        """
        return pulumi.get(self, "proxy_url")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The Region for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_REGION` environment
        variable
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        he Secret Key for Byteplus Provider. It must be provided, but it can also be sourced from the `BYTEPLUS_SECRET_KEY`
        environment variable
        """
        return pulumi.get(self, "secret_key")

    @pulumi.output_type
    class TerraformConfigResult:
        def __init__(__self__, result=None):
            if result and not isinstance(result, dict):
                raise TypeError("Expected argument 'result' to be a dict")
            pulumi.set(__self__, "result", result)

        @property
        @pulumi.getter
        def result(self) -> Mapping[str, Any]:
            return pulumi.get(self, "result")

    def terraform_config(__self__) -> pulumi.Output['Provider.TerraformConfigResult']:
        """
        This function returns a Terraform config object with terraform-namecased keys,to be used with the Terraform Module Provider.
        """
        __args__ = dict()
        __args__['__self__'] = __self__
        return pulumi.runtime.call('pulumi:providers:bytepluscc/terraformConfig', __args__, res=__self__, typ=Provider.TerraformConfigResult)




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['UpstreamArgs', 'Upstream']

@pulumi.input_type
class UpstreamArgs:
    def __init__(__self__, *,
                 gateway_id: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 source_type: pulumi.Input[builtins.str],
                 upstream_spec: pulumi.Input['UpstreamUpstreamSpecArgs'],
                 circuit_breaking_settings: Optional[pulumi.Input['UpstreamCircuitBreakingSettingsArgs']] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_settings: Optional[pulumi.Input['UpstreamLoadBalancerSettingsArgs']] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 tls_settings: Optional[pulumi.Input['UpstreamTlsSettingsArgs']] = None):
        """
        The set of arguments for constructing a Upstream resource.
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input[builtins.str] name: Upstream名称。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        :param pulumi.Input['UpstreamUpstreamSpecArgs'] upstream_spec: Upstream配置。
        :param pulumi.Input['UpstreamCircuitBreakingSettingsArgs'] circuit_breaking_settings: 服务熔断配置。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input['UpstreamLoadBalancerSettingsArgs'] load_balancer_settings: 负载均衡配置。
        :param pulumi.Input[builtins.str] protocol: 协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        :param pulumi.Input['UpstreamTlsSettingsArgs'] tls_settings: TLS配置。
        """
        pulumi.set(__self__, "gateway_id", gateway_id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "source_type", source_type)
        pulumi.set(__self__, "upstream_spec", upstream_spec)
        if circuit_breaking_settings is not None:
            pulumi.set(__self__, "circuit_breaking_settings", circuit_breaking_settings)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if load_balancer_settings is not None:
            pulumi.set(__self__, "load_balancer_settings", load_balancer_settings)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if tls_settings is not None:
            pulumi.set(__self__, "tls_settings", tls_settings)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Input[builtins.str]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        Upstream名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Input[builtins.str]:
        """
        Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter(name="upstreamSpec")
    def upstream_spec(self) -> pulumi.Input['UpstreamUpstreamSpecArgs']:
        """
        Upstream配置。
        """
        return pulumi.get(self, "upstream_spec")

    @upstream_spec.setter
    def upstream_spec(self, value: pulumi.Input['UpstreamUpstreamSpecArgs']):
        pulumi.set(self, "upstream_spec", value)

    @property
    @pulumi.getter(name="circuitBreakingSettings")
    def circuit_breaking_settings(self) -> Optional[pulumi.Input['UpstreamCircuitBreakingSettingsArgs']]:
        """
        服务熔断配置。
        """
        return pulumi.get(self, "circuit_breaking_settings")

    @circuit_breaking_settings.setter
    def circuit_breaking_settings(self, value: Optional[pulumi.Input['UpstreamCircuitBreakingSettingsArgs']]):
        pulumi.set(self, "circuit_breaking_settings", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="loadBalancerSettings")
    def load_balancer_settings(self) -> Optional[pulumi.Input['UpstreamLoadBalancerSettingsArgs']]:
        """
        负载均衡配置。
        """
        return pulumi.get(self, "load_balancer_settings")

    @load_balancer_settings.setter
    def load_balancer_settings(self, value: Optional[pulumi.Input['UpstreamLoadBalancerSettingsArgs']]):
        pulumi.set(self, "load_balancer_settings", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="tlsSettings")
    def tls_settings(self) -> Optional[pulumi.Input['UpstreamTlsSettingsArgs']]:
        """
        TLS配置。
        """
        return pulumi.get(self, "tls_settings")

    @tls_settings.setter
    def tls_settings(self, value: Optional[pulumi.Input['UpstreamTlsSettingsArgs']]):
        pulumi.set(self, "tls_settings", value)


@pulumi.input_type
class _UpstreamState:
    def __init__(__self__, *,
                 backend_targets: Optional[pulumi.Input[Sequence[pulumi.Input['UpstreamBackendTargetArgs']]]] = None,
                 circuit_breaking_settings: Optional[pulumi.Input['UpstreamCircuitBreakingSettingsArgs']] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_settings: Optional[pulumi.Input['UpstreamLoadBalancerSettingsArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 tls_settings: Optional[pulumi.Input['UpstreamTlsSettingsArgs']] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 upstream_id: Optional[pulumi.Input[builtins.str]] = None,
                 upstream_spec: Optional[pulumi.Input['UpstreamUpstreamSpecArgs']] = None,
                 version_details: Optional[pulumi.Input[Sequence[pulumi.Input['UpstreamVersionDetailArgs']]]] = None):
        """
        Input properties used for looking up and filtering Upstream resources.
        :param pulumi.Input['UpstreamCircuitBreakingSettingsArgs'] circuit_breaking_settings: 服务熔断配置。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.str] created_time: Upstream创建时间。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input['UpstreamLoadBalancerSettingsArgs'] load_balancer_settings: 负载均衡配置。
        :param pulumi.Input[builtins.str] name: Upstream名称。
        :param pulumi.Input[builtins.str] protocol: 协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        :param pulumi.Input['UpstreamTlsSettingsArgs'] tls_settings: TLS配置。
        :param pulumi.Input[builtins.str] updated_time: Upstream更新时间。
        :param pulumi.Input[builtins.str] upstream_id: Upstream ID。
        :param pulumi.Input['UpstreamUpstreamSpecArgs'] upstream_spec: Upstream配置。
        """
        if backend_targets is not None:
            pulumi.set(__self__, "backend_targets", backend_targets)
        if circuit_breaking_settings is not None:
            pulumi.set(__self__, "circuit_breaking_settings", circuit_breaking_settings)
        if comments is not None:
            pulumi.set(__self__, "comments", comments)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if gateway_id is not None:
            pulumi.set(__self__, "gateway_id", gateway_id)
        if load_balancer_settings is not None:
            pulumi.set(__self__, "load_balancer_settings", load_balancer_settings)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if tls_settings is not None:
            pulumi.set(__self__, "tls_settings", tls_settings)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if upstream_id is not None:
            pulumi.set(__self__, "upstream_id", upstream_id)
        if upstream_spec is not None:
            pulumi.set(__self__, "upstream_spec", upstream_spec)
        if version_details is not None:
            pulumi.set(__self__, "version_details", version_details)

    @property
    @pulumi.getter(name="backendTargets")
    def backend_targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UpstreamBackendTargetArgs']]]]:
        return pulumi.get(self, "backend_targets")

    @backend_targets.setter
    def backend_targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UpstreamBackendTargetArgs']]]]):
        pulumi.set(self, "backend_targets", value)

    @property
    @pulumi.getter(name="circuitBreakingSettings")
    def circuit_breaking_settings(self) -> Optional[pulumi.Input['UpstreamCircuitBreakingSettingsArgs']]:
        """
        服务熔断配置。
        """
        return pulumi.get(self, "circuit_breaking_settings")

    @circuit_breaking_settings.setter
    def circuit_breaking_settings(self, value: Optional[pulumi.Input['UpstreamCircuitBreakingSettingsArgs']]):
        pulumi.set(self, "circuit_breaking_settings", value)

    @property
    @pulumi.getter
    def comments(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @comments.setter
    def comments(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comments", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @gateway_id.setter
    def gateway_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_id", value)

    @property
    @pulumi.getter(name="loadBalancerSettings")
    def load_balancer_settings(self) -> Optional[pulumi.Input['UpstreamLoadBalancerSettingsArgs']]:
        """
        负载均衡配置。
        """
        return pulumi.get(self, "load_balancer_settings")

    @load_balancer_settings.setter
    def load_balancer_settings(self, value: Optional[pulumi.Input['UpstreamLoadBalancerSettingsArgs']]):
        pulumi.set(self, "load_balancer_settings", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_type", value)

    @property
    @pulumi.getter(name="tlsSettings")
    def tls_settings(self) -> Optional[pulumi.Input['UpstreamTlsSettingsArgs']]:
        """
        TLS配置。
        """
        return pulumi.get(self, "tls_settings")

    @tls_settings.setter
    def tls_settings(self, value: Optional[pulumi.Input['UpstreamTlsSettingsArgs']]):
        pulumi.set(self, "tls_settings", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="upstreamId")
    def upstream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Upstream ID。
        """
        return pulumi.get(self, "upstream_id")

    @upstream_id.setter
    def upstream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "upstream_id", value)

    @property
    @pulumi.getter(name="upstreamSpec")
    def upstream_spec(self) -> Optional[pulumi.Input['UpstreamUpstreamSpecArgs']]:
        """
        Upstream配置。
        """
        return pulumi.get(self, "upstream_spec")

    @upstream_spec.setter
    def upstream_spec(self, value: Optional[pulumi.Input['UpstreamUpstreamSpecArgs']]):
        pulumi.set(self, "upstream_spec", value)

    @property
    @pulumi.getter(name="versionDetails")
    def version_details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['UpstreamVersionDetailArgs']]]]:
        return pulumi.get(self, "version_details")

    @version_details.setter
    def version_details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['UpstreamVersionDetailArgs']]]]):
        pulumi.set(self, "version_details", value)


@pulumi.type_token("bytepluscc:apig/upstream:Upstream")
class Upstream(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 circuit_breaking_settings: Optional[pulumi.Input[Union['UpstreamCircuitBreakingSettingsArgs', 'UpstreamCircuitBreakingSettingsArgsDict']]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_settings: Optional[pulumi.Input[Union['UpstreamLoadBalancerSettingsArgs', 'UpstreamLoadBalancerSettingsArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 tls_settings: Optional[pulumi.Input[Union['UpstreamTlsSettingsArgs', 'UpstreamTlsSettingsArgsDict']]] = None,
                 upstream_spec: Optional[pulumi.Input[Union['UpstreamUpstreamSpecArgs', 'UpstreamUpstreamSpecArgsDict']]] = None,
                 __props__=None):
        """
        Upstream 是对 API 网关实例后端的抽象。您可以将具有相同功能的后端应用抽象为一个 Upstream，实现路由和后端应用解耦，更灵活地支持后端应用的灰度发布、多版本管理等场景。本文为您介绍 Upstream 的概念及作用。

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/upstream:Upstream example "upstream_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['UpstreamCircuitBreakingSettingsArgs', 'UpstreamCircuitBreakingSettingsArgsDict']] circuit_breaking_settings: 服务熔断配置。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input[Union['UpstreamLoadBalancerSettingsArgs', 'UpstreamLoadBalancerSettingsArgsDict']] load_balancer_settings: 负载均衡配置。
        :param pulumi.Input[builtins.str] name: Upstream名称。
        :param pulumi.Input[builtins.str] protocol: 协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        :param pulumi.Input[Union['UpstreamTlsSettingsArgs', 'UpstreamTlsSettingsArgsDict']] tls_settings: TLS配置。
        :param pulumi.Input[Union['UpstreamUpstreamSpecArgs', 'UpstreamUpstreamSpecArgsDict']] upstream_spec: Upstream配置。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UpstreamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Upstream 是对 API 网关实例后端的抽象。您可以将具有相同功能的后端应用抽象为一个 Upstream，实现路由和后端应用解耦，更灵活地支持后端应用的灰度发布、多版本管理等场景。本文为您介绍 Upstream 的概念及作用。

        ## Import

        ```sh
        $ pulumi import bytepluscc:apig/upstream:Upstream example "upstream_id"
        ```

        :param str resource_name: The name of the resource.
        :param UpstreamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UpstreamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 circuit_breaking_settings: Optional[pulumi.Input[Union['UpstreamCircuitBreakingSettingsArgs', 'UpstreamCircuitBreakingSettingsArgsDict']]] = None,
                 comments: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancer_settings: Optional[pulumi.Input[Union['UpstreamLoadBalancerSettingsArgs', 'UpstreamLoadBalancerSettingsArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 source_type: Optional[pulumi.Input[builtins.str]] = None,
                 tls_settings: Optional[pulumi.Input[Union['UpstreamTlsSettingsArgs', 'UpstreamTlsSettingsArgsDict']]] = None,
                 upstream_spec: Optional[pulumi.Input[Union['UpstreamUpstreamSpecArgs', 'UpstreamUpstreamSpecArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UpstreamArgs.__new__(UpstreamArgs)

            __props__.__dict__["circuit_breaking_settings"] = circuit_breaking_settings
            __props__.__dict__["comments"] = comments
            if gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'gateway_id'")
            __props__.__dict__["gateway_id"] = gateway_id
            __props__.__dict__["load_balancer_settings"] = load_balancer_settings
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["protocol"] = protocol
            if source_type is None and not opts.urn:
                raise TypeError("Missing required property 'source_type'")
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["tls_settings"] = tls_settings
            if upstream_spec is None and not opts.urn:
                raise TypeError("Missing required property 'upstream_spec'")
            __props__.__dict__["upstream_spec"] = upstream_spec
            __props__.__dict__["backend_targets"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["upstream_id"] = None
            __props__.__dict__["version_details"] = None
        super(Upstream, __self__).__init__(
            'bytepluscc:apig/upstream:Upstream',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend_targets: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UpstreamBackendTargetArgs', 'UpstreamBackendTargetArgsDict']]]]] = None,
            circuit_breaking_settings: Optional[pulumi.Input[Union['UpstreamCircuitBreakingSettingsArgs', 'UpstreamCircuitBreakingSettingsArgsDict']]] = None,
            comments: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            gateway_id: Optional[pulumi.Input[builtins.str]] = None,
            load_balancer_settings: Optional[pulumi.Input[Union['UpstreamLoadBalancerSettingsArgs', 'UpstreamLoadBalancerSettingsArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            source_type: Optional[pulumi.Input[builtins.str]] = None,
            tls_settings: Optional[pulumi.Input[Union['UpstreamTlsSettingsArgs', 'UpstreamTlsSettingsArgsDict']]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            upstream_id: Optional[pulumi.Input[builtins.str]] = None,
            upstream_spec: Optional[pulumi.Input[Union['UpstreamUpstreamSpecArgs', 'UpstreamUpstreamSpecArgsDict']]] = None,
            version_details: Optional[pulumi.Input[Sequence[pulumi.Input[Union['UpstreamVersionDetailArgs', 'UpstreamVersionDetailArgsDict']]]]] = None) -> 'Upstream':
        """
        Get an existing Upstream resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['UpstreamCircuitBreakingSettingsArgs', 'UpstreamCircuitBreakingSettingsArgsDict']] circuit_breaking_settings: 服务熔断配置。
        :param pulumi.Input[builtins.str] comments: 备注。
        :param pulumi.Input[builtins.str] created_time: Upstream创建时间。
        :param pulumi.Input[builtins.str] gateway_id: 网关实例ID。
        :param pulumi.Input[Union['UpstreamLoadBalancerSettingsArgs', 'UpstreamLoadBalancerSettingsArgsDict']] load_balancer_settings: 负载均衡配置。
        :param pulumi.Input[builtins.str] name: Upstream名称。
        :param pulumi.Input[builtins.str] protocol: 协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        :param pulumi.Input[builtins.str] source_type: Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        :param pulumi.Input[Union['UpstreamTlsSettingsArgs', 'UpstreamTlsSettingsArgsDict']] tls_settings: TLS配置。
        :param pulumi.Input[builtins.str] updated_time: Upstream更新时间。
        :param pulumi.Input[builtins.str] upstream_id: Upstream ID。
        :param pulumi.Input[Union['UpstreamUpstreamSpecArgs', 'UpstreamUpstreamSpecArgsDict']] upstream_spec: Upstream配置。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UpstreamState.__new__(_UpstreamState)

        __props__.__dict__["backend_targets"] = backend_targets
        __props__.__dict__["circuit_breaking_settings"] = circuit_breaking_settings
        __props__.__dict__["comments"] = comments
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["gateway_id"] = gateway_id
        __props__.__dict__["load_balancer_settings"] = load_balancer_settings
        __props__.__dict__["name"] = name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["tls_settings"] = tls_settings
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["upstream_id"] = upstream_id
        __props__.__dict__["upstream_spec"] = upstream_spec
        __props__.__dict__["version_details"] = version_details
        return Upstream(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backendTargets")
    def backend_targets(self) -> pulumi.Output[Sequence['outputs.UpstreamBackendTarget']]:
        return pulumi.get(self, "backend_targets")

    @property
    @pulumi.getter(name="circuitBreakingSettings")
    def circuit_breaking_settings(self) -> pulumi.Output['outputs.UpstreamCircuitBreakingSettings']:
        """
        服务熔断配置。
        """
        return pulumi.get(self, "circuit_breaking_settings")

    @property
    @pulumi.getter
    def comments(self) -> pulumi.Output[builtins.str]:
        """
        备注。
        """
        return pulumi.get(self, "comments")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        Upstream创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="gatewayId")
    def gateway_id(self) -> pulumi.Output[builtins.str]:
        """
        网关实例ID。
        """
        return pulumi.get(self, "gateway_id")

    @property
    @pulumi.getter(name="loadBalancerSettings")
    def load_balancer_settings(self) -> pulumi.Output['outputs.UpstreamLoadBalancerSettings']:
        """
        负载均衡配置。
        """
        return pulumi.get(self, "load_balancer_settings")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Upstream名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        协议，取值：HTTP：HTTP/1.1。HTTP2：HTTP/2。GRPC：GRPC。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[builtins.str]:
        """
        Upstream来源类型，取值：VeFaas：函数服务。ECS：云服务器。K8S：容器服务。Nacos：注册中心。AIProvider：AI模型代理。
        """
        return pulumi.get(self, "source_type")

    @property
    @pulumi.getter(name="tlsSettings")
    def tls_settings(self) -> pulumi.Output['outputs.UpstreamTlsSettings']:
        """
        TLS配置。
        """
        return pulumi.get(self, "tls_settings")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        Upstream更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="upstreamId")
    def upstream_id(self) -> pulumi.Output[builtins.str]:
        """
        Upstream ID。
        """
        return pulumi.get(self, "upstream_id")

    @property
    @pulumi.getter(name="upstreamSpec")
    def upstream_spec(self) -> pulumi.Output['outputs.UpstreamUpstreamSpec']:
        """
        Upstream配置。
        """
        return pulumi.get(self, "upstream_spec")

    @property
    @pulumi.getter(name="versionDetails")
    def version_details(self) -> pulumi.Output[Sequence['outputs.UpstreamVersionDetail']]:
        return pulumi.get(self, "version_details")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'CenTagArgs',
    'CenTagArgsDict',
]

MYPY = False

if not MYPY:
    class CenTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签键。长度限制为1～128个字符。大小写敏感，不能以空格开头或结尾。允许包含字母、数字、空格（）、下划线（_）、点号（.）、半角冒号（:）、斜杠（/）、等号（=）、加号（+）、减号（-）和@。同一资源的标签键不允许重复
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        用户标签的标签值。长度限制为0～256个字符。大小写敏感，不能以空格开头或结尾。允许包含字母、数字、空格（）、下划线（_）、点号（.）、半角冒号（:）、斜杠（/）、等号（=）、加号（+）、减号（-）和@
        """
elif False:
    CenTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class CenTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 用户标签的标签键。长度限制为1～128个字符。大小写敏感，不能以空格开头或结尾。允许包含字母、数字、空格（）、下划线（_）、点号（.）、半角冒号（:）、斜杠（/）、等号（=）、加号（+）、减号（-）和@。同一资源的标签键不允许重复
        :param pulumi.Input[builtins.str] value: 用户标签的标签值。长度限制为0～256个字符。大小写敏感，不能以空格开头或结尾。允许包含字母、数字、空格（）、下划线（_）、点号（.）、半角冒号（:）、斜杠（/）、等号（=）、加号（+）、减号（-）和@
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签键。长度限制为1～128个字符。大小写敏感，不能以空格开头或结尾。允许包含字母、数字、空格（）、下划线（_）、点号（.）、半角冒号（:）、斜杠（/）、等号（=）、加号（+）、减号（-）和@。同一资源的标签键不允许重复
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户标签的标签值。长度限制为0～256个字符。大小写敏感，不能以空格开头或结尾。允许包含字母、数字、空格（）、下划线（_）、点号（.）、半角冒号（:）、斜杠（/）、等号（=）、加号（+）、减号（-）和@
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


